.onAttach <- function(libname, pkgname) {
  packageStartupMessage("##\n## ebal Package: Implements Entropy Balancing.\n")
  packageStartupMessage("## See https://web.stanford.edu/~jhain/ for additional information.\n")
}

